# Koalak

<img src="https://raw.githubusercontent.com/Nazime/koalak/refs/heads/main/images/koalak_logo.png" alt="Koalak Logo" width="300">

**Koalak** is a Python library designed to simplify the development of applications with a plugin-based architecture. The main module, `plugin_manager`, provides robust tools to manage plugins efficiently and reduce boilerplate code.


## Documentation

https://nazime.github.io/koalak/

## Install

```bash
pip install koalak
```
